@@ -137,7 +137,7 @@ c     pzneigh  Parallel ARPACK compute Ritz values and error bounds routine.
 c     pzngets  Parallel ARPACK reorder Ritz values and error bounds routine.
 c     zsortc   ARPACK sorting routine.
 c     pivout   Parallel ARPACK utility routine that prints integers.
-c     second   ARPACK utility routine for timing.
+c     arscnd   ARPACK utility routine for timing.
 c     pzmout   Parallel ARPACK utility routine that prints matrices
 c     pzvout   Parallel ARPACK utility routine that prints vectors.
 c     pdvout   ARPACK utility routine that prints vectors.
@@ -247,7 +247,7 @@ c     | External Subroutines |
 c     %----------------------%
 c
       external   zcopy, pzgetv0, pznaitr, pzneigh, pzngets, pznapps,
-     &           zsortc, zswap, pzmout, pzvout, pivout, second
+     &           zsortc, zswap, pzmout, pzvout, pivout, arscnd
 c
 c     %--------------------%
 c     | External functions |
@@ -271,7 +271,7 @@ c     %-----------------------%
 c
       if (ido .eq. 0) then
 c 
-         call second (t0)
+         call arscnd (t0)
 c 
          msglvl = mcaup2
 c 
@@ -737,7 +737,7 @@ c        | the first step of the next call to pznaitr. |
 c        %---------------------------------------------%
 c
          cnorm = .true.
-         call second (t2)
+         call arscnd (t2)
          if (bmat .eq. 'G') then
             nbx = nbx + 1
             call zcopy (n, resid, 1, workd(n+1), 1)
@@ -762,7 +762,7 @@ c        | WORKD(1:N) := B*RESID            |
 c        %----------------------------------%
 c
          if (bmat .eq. 'G') then
-            call second (t3)
+            call arscnd (t3)
             tmvbx = tmvbx + (t3 - t2)
          end if
 c 
@@ -802,7 +802,7 @@ c     %------------%
 c     | Error Exit |
 c     %------------%
 c
-      call second (t1)
+      call arscnd (t1)
       tcaup2 = t1 - t0
 c     
  9000 continue
